@@ -26,6 +26,9 @@ class CSVParser():
 
         self.validate()
 
+        if len(self.df) == 0:
+            print("Error: Dataframe empty. Is the CSV file ok?")
+
         self.df = self.df.astype('object')
 
         self.header = list(self.df.columns.values)
@@ -44,7 +47,9 @@ class CSVParser():
                     prop = key[len("date:"):] # remove prefix
                     properties[prop] = {"_date": self.df.loc[idx, key]}
                 else:
-                    properties[key] = self.df.loc[idx, key]
+                    value = self.df.loc[idx, key]
+                    if value == value:  # skips nan values
+                        properties[key] = value
 
         return properties
 
